.. _credits:

*******
Credits
*******


Quantities was written by Darren Dale, with the hope that additional
developers will contribute to --- and take credit for --- its 
development.

Special thanks to those who have made valuable contributions
(roughly in order of first contribution by date)

Charles Doutriaux
  wrote the python wrapper for unit conversions with the UDUnits 
  library (no longer used)

Enthought Inc.
  the original units registry was developed at Enthought for the 
  Enthought Tool Suite.

John Salvatier
  added support for the Quantity iterator, contributed to support for 
  simplified representations of units, comparison operators, and 
  contributed unit tests.

Tony Yu
  contributed several bug fixes and contributed to the documentation.
